@@ -55,6 +55,8 @@ class MsgPackSerializer(hishel.BaseSerializer):
     DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%S.%fZ"
 
     def dumps(self, response: Response, request: Request, metadata: Metadata) -> bytes:
+        from hishel._utils import normalized_url
+
         response_dict = {
             "status": response.status,
             "headers": response.headers,
@@ -66,7 +68,7 @@ class MsgPackSerializer(hishel.BaseSerializer):
 
         request_dict = {
             "method": request.method.decode("ascii"),
-            "url": str(request.url),
+            "url": normalized_url(request.url),
             "headers": request.headers,
             "extensions": {
                 key: value for key, value in request.extensions.items() if key in self.KNOWN_REQUEST_EXTENSIONS
@@ -132,20 +134,24 @@ class PDMPyPIClient(PyPIClient):
 
         mounts: dict[str, httpx.BaseTransport] = {"file://": LocalFSTransport()}
         self._trusted_host_ports: set[tuple[str, int | None]] = set()
-        transport: httpx.BaseTransport | None = None
         for s in sources:
-            if s.name == "pypi":
-                transport = self._transport_for(s)
-                continue
             assert s.url is not None
             url = httpx.URL(s.url)
+            if s.verify_ssl is False:
+                self._trusted_host_ports.add((url.host, url.port))
+            if s.name == "pypi":
+                kwargs["transport"] = self._transport_for(s)
+                continue
             mounts[f"{url.scheme}://{url.netloc.decode('ascii')}/"] = hishel.CacheTransport(
                 self._transport_for(s), storage, controller
             )
-            self._trusted_host_ports.add((url.host, url.port))
         mounts.update(kwargs.pop("mounts", None) or {})
+        kwargs.update(
+            proxies=self._get_proxy_map(None, allow_env_proxies=True),
+            follow_redirects=True,
+        )
 
-        httpx.Client.__init__(self, mounts=mounts, follow_redirects=True, transport=transport, **kwargs)
+        httpx.Client.__init__(self, mounts=mounts, **kwargs)
 
         self.headers["User-Agent"] = self._make_user_agent()
         self.event_hooks["response"].append(self.on_response)
